@@ -998,8 +998,8 @@ def main():
         sys.exit(EX_USAGE)
 
     except HTTPResponseError as e:
-        if e.status_code == 401:
-            error(u"Owncloud response error: %s, Username and password do not match, or your password has been expired." % e)
+        if e.status_code in HTTP_ERROR_HINT.keys():
+            error(u"Owncloud response error: %s, %s" % (e, HTTP_ERROR_HINT[e.status_code]))
         else:
             error(u"Owncloud response error: %s" % e)
         sys.exit(e.get_error_code())
